@@ -25,7 +25,7 @@ def get_nearest_index(tim_eq, tarr):
     return unique_idx, idx
 
 
-def rho2rho(eqsf, rho_in, t_in=None, \
+def rho2rho(eqm, rho_in, t_in=None, \
            coord_in='rho_pol', coord_out='rho_tor', extrapolate=False):
 
     """Mapping from/to rho_pol, rho_tor, r_V, rho_V, Psi, r_a
@@ -51,7 +51,7 @@ def rho2rho(eqsf, rho_in, t_in=None, \
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr = np.atleast_1d(t_in)
     rho = np.atleast_1d(rho_in)
@@ -65,45 +65,45 @@ def rho2rho(eqsf, rho_in, t_in=None, \
     if coord_out == coord_in: 
         return rho
  
-    unique_idx, idx =  get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx =  get_nearest_index(eqm.time, tarr)
 
     if coord_in in ['rho_pol', 'Psi']:
-        label_in = eqsf.pfl
+        label_in = eqm.pfl
     elif coord_in == 'rho_tor':
-        label_in = eqsf.tfl
+        label_in = eqm.tfl
     elif coord_in in ['rho_V','r_V']:
-        label_in = eqsf.vol
-        R0 = eqsf.Rmag
+        label_in = eqm.vol
+        R0 = eqm.Rmag
     elif coord_in == 'r_a':
-        R, _ = rhoTheta2rz(eqsf, eqsf.pfl, [0, np.pi], coord_in='Psi')
+        R, _ = rhoTheta2rz(eqm, eqm.pfl, [0, np.pi], coord_in='Psi')
         label_in = (R[:, 0] - R[:, 1]).T**2
     else:
         raise Exception('unsupported input coordinate')
 
     if coord_out in ['rho_pol', 'Psi']:
-        label_out = eqsf.pfl
+        label_out = eqm.pfl
     elif coord_out == 'rho_tor':
-        label_out = eqsf.tfl
+        label_out = eqm.tfl
     elif coord_out in ['rho_V','r_V']:
-        label_out = eqsf.vol
-        R0 = eqsf.Rmag
+        label_out = eqm.vol
+        R0 = eqm.Rmag
     elif coord_out == 'r_a':
-        R, _ = rhoTheta2rz(eqsf, eqsf.pfl[unique_idx], [0, np.pi], \
-                    t_in=eqsf.time[unique_idx], coord_in='Psi')
-        label_out = np.zeros_like(eqsf.pfl)
+        R, _ = rhoTheta2rz(eqm, eqm.pfl[unique_idx], [0, np.pi], \
+                    t_in=eqm.time[unique_idx], coord_in='Psi')
+        label_out = np.zeros_like(eqm.pfl)
         label_out[unique_idx, :] = (R[:, 0] - R[:, 1])**2
     else:
         raise Exception('unsupported output coordinate')
 
-    PFL  = eqsf.orientation*eqsf.pfl
-    PSIX = eqsf.orientation*eqsf.psix
-    PSI0 = eqsf.orientation*eqsf.psi0
+    PFL  = eqm.orientation*eqm.pfl
+    PSIX = eqm.orientation*eqm.psix
+    PSI0 = eqm.orientation*eqm.psi0
     rho_output = np.zeros_like(rho)
 
     for i in unique_idx:
   
 # Calculate a normalized input and output flux 
-#            sort_wh = eqsf.ind_sort[i][:eqsf.lpfp[i]]    # Up to separatrix   
+#            sort_wh = eqm.ind_sort[i][:eqm.lpfp[i]]    # Up to separatrix   
 
         sep_out, mag_out = np.interp([PSIX[i], PSI0[i]], PFL[i], label_out[i])
         sep_in , mag_in  = np.interp([PSIX[i], PSI0[i]], PFL[i], label_in [i])
@@ -149,7 +149,7 @@ def rho2rho(eqsf, rho_in, t_in=None, \
             r0_out = np.sqrt(sep_out/(2*np.pi**2*R0[i]))
 
         if coord_in == 'Psi' :
-            rho_  = np.sqrt(np.maximum(0, (rho_ - eqsf.psi0[i])/(eqsf.psix[i] - eqsf.psi0[i])))
+            rho_  = np.sqrt(np.maximum(0, (rho_ - eqm.psi0[i])/(eqm.psix[i] - eqm.psi0[i])))
 
 # Evaluate spline
 
@@ -164,12 +164,12 @@ def rho2rho(eqsf, rho_in, t_in=None, \
         rho_output[jt] = np.maximum(0,rho_output[jt]) # rounding errors
 
         if coord_out  == 'Psi':
-            rho_output[jt]  = rho_output[jt]**2*(eqsf.psix[i] - eqsf.psi0[i]) + eqsf.psi0[i]
+            rho_output[jt]  = rho_output[jt]**2*(eqm.psix[i] - eqm.psi0[i]) + eqm.psi0[i]
     
     return rho_output
 
 
-def rz2brzt(eqsf, r_in, z_in, t_in=None):
+def rz2brzt(eqm, r_in, z_in, t_in=None):
 
     """calculates Br, Bz, Bt profiles
     Input
@@ -195,7 +195,7 @@ def rz2brzt(eqsf, r_in, z_in, t_in=None):
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
         
     tarr = np.atleast_1d(t_in)
     r_in = np.atleast_1d(r_in)
@@ -221,16 +221,16 @@ def rz2brzt(eqsf, r_in, z_in, t_in=None):
     interpBt = np.zeros((nt, nrz_in), dtype=np.float32)
 
     from scipy.constants import mu_0
-    nr, nz = len(eqsf.Rmesh), len(eqsf.Zmesh)
-    dr = (eqsf.Rmesh[-1] - eqsf.Rmesh[0])/float(nr - 1)
-    dz = (eqsf.Zmesh[-1] - eqsf.Zmesh[0])/float(nz - 1)
+    nr, nz = len(eqm.Rmesh), len(eqm.Zmesh)
+    dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/float(nr - 1)
+    dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/float(nz - 1)
 
 # COCOS, Eq. 19, 24
-    cocos_in = eqsf.cocos
+    cocos_in = eqm.cocos
     jc_in    = cocos_in%10 - 1
     ebp_in   = cocos_in//10
-    sign_ip  = np.sign(np.nanmean(eqsf.ipipsi))
-    sign_b0  = np.sign(np.nanmean(eqsf.jpol))
+    sign_ip  = np.sign(np.nanmean(eqm.ipipsi))
+    sign_b0  = np.sign(np.nanmean(eqm.jpol))
     sigma_ip = sign_ip*cocos.sigma['rphiz'][jc_in]
     sigma_b0 = sign_b0*cocos.sigma['rphiz'][jc_in]
     phi_sign = sigma_b0
@@ -239,21 +239,21 @@ def rz2brzt(eqsf, r_in, z_in, t_in=None):
     psi_fac = psi_sign*psi_2pi
     print('COCOS %d, Sign Bt %d, Sign Ip %d' %(cocos_in, sign_b0, sign_ip))
 
-    unique_idx, idx =  get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx =  get_nearest_index(eqm.time, tarr)
 
     for i in unique_idx:
 
         jt = (idx == i)
-        Psi = eqsf.pfm[:, :, i]
-        Br =  np.gradient(Psi, axis=1)/eqsf.Rmesh[:, None]
-        Bz = -np.gradient(Psi, axis=0)/eqsf.Rmesh[:, None]
-        fBt = interp1d(eqsf.pfl[i], eqsf.jpol[i], kind='linear', fill_value='extrapolate')
-        Bt = fBt(Psi)*mu_0/eqsf.Rmesh[:, None]
+        Psi = eqm.pfm[:, :, i]
+        Br =  np.gradient(Psi, axis=1)/eqm.Rmesh[:, None]
+        Bz = -np.gradient(Psi, axis=0)/eqm.Rmesh[:, None]
+        fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
+        Bt = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
         r = np.squeeze(r_in[jt])
         z = np.squeeze(z_in[jt])
-        f_br = RectBivariateSpline(eqsf.Rmesh, eqsf.Zmesh, Br, kx=2, ky=2)
-        f_bz = RectBivariateSpline(eqsf.Rmesh, eqsf.Zmesh, Bz, kx=2, ky=2)
-        f_bt = RectBivariateSpline(eqsf.Rmesh, eqsf.Zmesh, Bt, kx=2, ky=2)
+        f_br = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Br, kx=2, ky=2)
+        f_bz = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Bz, kx=2, ky=2)
+        f_bt = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Bt, kx=2, ky=2)
         interpBr[jt] = f_br(r, z, grid=False)
         interpBz[jt] = f_bz(r, z, grid=False)
         interpBt[jt] = f_bt(r, z, grid=False)
@@ -263,7 +263,7 @@ def rz2brzt(eqsf, r_in, z_in, t_in=None):
            np.abs(interpBt)/psi_2pi * phi_sign
 
 
-def Bmesh(eqsf, t_in=None):
+def Bmesh(eqm, t_in=None):
 
     """calculates Br, Bz, Bt profiles
     Input
@@ -282,7 +282,7 @@ def Bmesh(eqsf, t_in=None):
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr = np.atleast_1d(t_in)
     nt = len(tarr)
@@ -291,17 +291,17 @@ def Bmesh(eqsf, t_in=None):
 
     from scipy.constants import mu_0
 
-    nr = len(eqsf.Rmesh)
-    nz = len(eqsf.Zmesh)
-    dr = (eqsf.Rmesh[-1] - eqsf.Rmesh[0])/float(nr - 1)
-    dz = (eqsf.Zmesh[-1] - eqsf.Zmesh[0])/float(nz - 1)
+    nr = len(eqm.Rmesh)
+    nz = len(eqm.Zmesh)
+    dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/float(nr - 1)
+    dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/float(nz - 1)
 
 # COCOS, Eq. 24
-    cocos_in = eqsf.cocos
+    cocos_in = eqm.cocos
     jc_in    = cocos_in%10 - 1
     ebp_in   = cocos_in//10
-    sign_ip  =  eqsf.orientation
-    sign_b0  = -eqsf.orientation
+    sign_ip  =  eqm.orientation
+    sign_b0  = -eqm.orientation
     sigma_ip = sign_ip*cocos.sigma['rphiz'][jc_in]
     sigma_b0 = sign_b0*cocos.sigma['rphiz'][jc_in]
     phi_sign = sigma_b0
@@ -310,7 +310,7 @@ def Bmesh(eqsf, t_in=None):
     psi_fac = psi_sign*psi_2pi
     print('COCOS %d' %cocos_in)
 
-    unique_idx, idx =  get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx =  get_nearest_index(eqm.time, tarr)
 
     Br = np.zeros((nt, nr, nz), dtype=np.float32)
     Bz = np.zeros_like(Br)
@@ -318,19 +318,19 @@ def Bmesh(eqsf, t_in=None):
     for i in unique_idx:
 
         jt = (idx == i)
-        Psi = eqsf.pfm[:, :, i]
+        Psi = eqm.pfm[:, :, i]
 # Eq 12 in COCOs paper
-        Br[jt] = np.gradient(Psi, axis=1)/eqsf.Rmesh[:, None]
-        Bz[jt] = -np.gradient(Psi, axis=0)/eqsf.Rmesh[:, None]
-        fBt = interp1d(eqsf.pfl[i], eqsf.jpol[i], kind='linear', fill_value='extrapolate')
-        Bt[jt] = fBt(Psi)*mu_0/eqsf.Rmesh[:, None]
+        Br[jt] = np.gradient(Psi, axis=1)/eqm.Rmesh[:, None]
+        Bz[jt] = -np.gradient(Psi, axis=0)/eqm.Rmesh[:, None]
+        fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
+        Bt[jt] = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
 
     return Br/(psi_fac*dz), \
            Bz/(psi_fac*dr), \
            Bt/psi_2pi * phi_sign
 
 
-def rz2rho(eqsf, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
+def rz2rho(eqm, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
 
     """
     Equilibrium mapping routine, map from R,Z -> rho (pol,tor,r_V,...)
@@ -358,14 +358,14 @@ def rz2rho(eqsf, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr = np.atleast_1d(t_in)
     r_in = np.atleast_2d(r_in)
     z_in = np.atleast_2d(z_in)
 
-    dr = (eqsf.Rmesh[-1] - eqsf.Rmesh[0])/(len(eqsf.Rmesh) - 1)
-    dz = (eqsf.Zmesh[-1] - eqsf.Zmesh[0])/(len(eqsf.Zmesh) - 1)
+    dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/(len(eqm.Rmesh) - 1)
+    dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/(len(eqm.Zmesh) - 1)
 
     nt_in = np.size(tarr)
 
@@ -388,9 +388,9 @@ def rz2rho(eqsf, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
     Psi = np.empty((nt_in,)+r_in.shape[1:], dtype=np.single)
 
     scaling = np.array([dr, dz])
-    offset  = np.array([eqsf.Rmesh[0], eqsf.Zmesh[0]])
+    offset  = np.array([eqm.Rmesh[0], eqm.Zmesh[0]])
     
-    unique_idx, idx =  get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx =  get_nearest_index(eqm.time, tarr)
   
     for i in unique_idx:
         if len(idx) == 1:
@@ -399,17 +399,17 @@ def rz2rho(eqsf, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
             jt = idx == i
         coords = np.array((r_in[jt], z_in[jt]))
         index = ((coords.T - offset) / scaling).T
-        Psi[jt] =  map_coordinates(eqsf.pfm[:, :, i], index, mode='nearest',
+        Psi[jt] =  map_coordinates(eqm.pfm[:, :, i], index, mode='nearest',
                                    order=2, prefilter=True)
 
     t1 = time.time()
-    rho_out = rho2rho(eqsf, Psi, t_in=t_in, extrapolate=extrapolate, \
+    rho_out = rho2rho(eqm, Psi, t_in=t_in, extrapolate=extrapolate, \
               coord_in='Psi', coord_out=coord_out)
     t2 = time.time()
     return rho_out
 
 
-def rho2rz(eqsf, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
+def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
 
     """
     Get R, Z coordinates of a flux surfaces contours
@@ -434,23 +434,23 @@ def rho2rz(eqsf, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr  = np.atleast_1d(t_in)
     rhoin = np.atleast_1d(rho_in)
 
-    rho_in = rho2rho(eqsf, rhoin, t_in=t_in, \
+    rho_in = rho2rho(eqm, rhoin, t_in=t_in, \
              coord_in=coord_in, coord_out='Psi', extrapolate=True )
 
     from matplotlib import _contour
 
-    nr = len(eqsf.Rmesh)
-    nz = len(eqsf.Zmesh)
+    nr = len(eqm.Rmesh)
+    nz = len(eqm.Zmesh)
 
-    R, Z = np.meshgrid(eqsf.Rmesh, eqsf.Zmesh)
+    R, Z = np.meshgrid(eqm.Rmesh, eqm.Zmesh)
     Rsurf = np.empty(len(tarr), dtype='object')
     zsurf = np.empty(len(tarr), dtype='object')
-    unique_idx, idx =  get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx =  get_nearest_index(eqm.time, tarr)
 
     for i in unique_idx:
 
@@ -459,9 +459,9 @@ def rho2rz(eqsf, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
         
 # matplotlib's contour creation
         try:
-            cgen = _contour.QuadContourGenerator(R, Z, eqsf.pfm[:nr, :nz, i].T, None, True, 0)
+            cgen = _contour.QuadContourGenerator(R, Z, eqm.pfm[:nr, :nz, i].T, None, True, 0)
         except Exception as e:
-            print(R.shape, Z.shape, eqsf.pfm[:nr, :nz, i].T.shape)
+            print(R.shape, Z.shape, eqm.pfm[:nr, :nz, i].T.shape)
             raise e 
 
         Rs_t = []
@@ -471,9 +471,9 @@ def rho2rz(eqsf, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
             segs = cgen.create_contour(fl)
             n_segs = len(segs)
             if n_segs == 0:
-                if fl == eqsf.psi0[i]:
-                    Rs_t.append(np.atleast_1d(eqsf.Rmag[i]))
-                    zs_t.append(np.atleast_1d(eqsf.Zmag[i]))
+                if fl == eqm.psi0[i]:
+                    Rs_t.append(np.atleast_1d(eqm.Rmag[i]))
+                    zs_t.append(np.atleast_1d(eqm.Zmag[i]))
                 else:
                     Rs_t.append(np.zeros(1))
                     zs_t.append(np.zeros(1))
@@ -490,7 +490,7 @@ def rho2rz(eqsf, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
             R_surf = np.array(R_surf, dtype = np.float32)
             z_surf = np.array(z_surf, dtype = np.float32)
             if not all_lines:
-                ind = (z_surf >= eqsf.Zunt[i])
+                ind = (z_surf >= eqm.Zunt[i])
                 if len(ind) > 1:
                     R_surf = R_surf[ind]
                     z_surf = z_surf[ind]
@@ -504,7 +504,7 @@ def rho2rz(eqsf, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
     return Rsurf, zsurf
 
 
-def cross_surf(eqsf, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in='rho_pol'):
+def cross_surf(eqm, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in='rho_pol'):
 
     """
     Computes intersections of a line with any flux surface.
@@ -533,14 +533,14 @@ def cross_surf(eqsf, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in=
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr = np.atleast_1d(t_in)
     rho  = np.float32(rho)
     r_in = np.float32(r_in)
     z_in = np.float32(z_in)
 
-    unique_idx, idx = get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx = get_nearest_index(eqm.time, tarr)
 
     line_m = 3. # line length: 6 m
     n_line = int(200*line_m) + 1 # 1 cm, but then there's interpolation!
@@ -549,13 +549,13 @@ def cross_surf(eqsf, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in=
     t1 = time.time()
     line_r = t*np.cos(theta_in) + r_in
     line_z = t*np.sin(theta_in) + z_in
-    rho_line = rz2rho(eqsf, line_r, line_z, t_in=eqsf.time[unique_idx], \
+    rho_line = rz2rho(eqm, line_r, line_z, t_in=eqm.time[unique_idx], \
                            coord_out=coord_in, extrapolate=True)
 
     t2 = time.time()
     if coord_in == 'Psi':
-        rho_line *= eqsf.orientation
-        rho      *= eqsf.orientation
+        rho_line *= eqm.orientation
+        rho      *= eqm.orientation
     nt_in = len(tarr)
     Rout = np.zeros((nt_in, 2), dtype=np.float32)
     zout = np.zeros((nt_in, 2), dtype=np.float32)
@@ -579,7 +579,7 @@ def cross_surf(eqsf, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in=
             else:
                 ind = [j + 1, j]
             ztmp = np.interp(rho, rho_line[i, ind], line_z[ind])
-            if ztmp >= eqsf.Zunt[ii] and ztmp <= eqsf.Zoben[ii]:
+            if ztmp >= eqm.Zunt[ii] and ztmp <= eqm.Zoben[ii]:
                 zout[jt, pos] = ztmp
                 Rout[jt, pos] = np.interp(rho, rho_line[i, ind], line_r[ind])
                 pos += 1
@@ -588,7 +588,7 @@ def cross_surf(eqsf, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in=
     return Rout, zout
 
 
-def cross_sep(eqsf, r_in=1.65, z_in=0, theta_in=0, t_in=None):
+def cross_sep(eqm, r_in=1.65, z_in=0, theta_in=0, t_in=None):
 
     """
     Computes intersections of a line with any flux surface.
@@ -613,13 +613,13 @@ def cross_sep(eqsf, r_in=1.65, z_in=0, theta_in=0, t_in=None):
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr = np.atleast_1d(t_in)
     r_in = np.float32(r_in)
     z_in = np.float32(z_in)
 
-    unique_idx, idx = get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx = get_nearest_index(eqm.time, tarr)
 
     line_m = 3. # line length: 6 m
     n_line = int(200*line_m) + 1 # 1 cm, but then there's interpolation!
@@ -628,12 +628,12 @@ def cross_sep(eqsf, r_in=1.65, z_in=0, theta_in=0, t_in=None):
     t1 = time.time()
     line_r = t*np.cos(theta_in) + r_in
     line_z = t*np.sin(theta_in) + z_in
-    psi_line = rz2rho(eqsf, line_r, line_z, t_in=eqsf.time[unique_idx], \
+    psi_line = rz2rho(eqm, line_r, line_z, t_in=eqm.time[unique_idx], \
                            coord_out='Psi', extrapolate=True)
 
     t2 = time.time()
-    psi_line *= eqsf.orientation
-    psi_sep = eqsf.pfl[:, max(eqsf.lpfp)]*eqsf.orientation
+    psi_line *= eqm.orientation
+    psi_sep = eqm.pfl[:, max(eqm.lpfp)]*eqm.orientation
     nt_in = len(tarr)
     Rout = np.zeros((nt_in, 2), dtype=np.float32)
     zout = np.zeros((nt_in, 2), dtype=np.float32)
@@ -657,7 +657,7 @@ def cross_sep(eqsf, r_in=1.65, z_in=0, theta_in=0, t_in=None):
             else:
                 ind = [j + 1, j]
             ztmp = np.interp(psi_sep[ii], psi_line[i, ind], line_z[ind])
-            if ztmp >= eqsf.Zunt[ii] and ztmp <= eqsf.Zoben[ii]:
+            if ztmp >= eqm.Zunt[ii] and ztmp <= eqm.Zoben[ii]:
                 zout[jt, pos] = ztmp
                 Rout[jt, pos] = np.interp(psi_sep[ii], psi_line[i, ind], line_r[ind])
                 pos += 1
@@ -666,7 +666,7 @@ def cross_sep(eqsf, r_in=1.65, z_in=0, theta_in=0, t_in=None):
     return Rout, zout
 
 
-def rhoTheta2rz(eqsf, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
+def rhoTheta2rz(eqm, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     
     """
     This routine calculates the coordinates R, z of the intersections of
@@ -693,7 +693,7 @@ def rhoTheta2rz(eqsf, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     """
 
     if t_in is None:
-        t_in = eqsf.time
+        t_in = eqm.time
 
     tarr = np.atleast_1d(t_in)
 
@@ -706,7 +706,7 @@ def rhoTheta2rz(eqsf, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     theta_in = np.atleast_1d(theta_in)[:, None]
     ntheta = len(theta_in)
 
-    unique_idx, idx = get_nearest_index(eqsf.time, tarr)
+    unique_idx, idx = get_nearest_index(eqm.time, tarr)
 
 #        n_line = 201 <=> 5 mm, but then there's interpolation!
 
@@ -720,19 +720,19 @@ def rhoTheta2rz(eqsf, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     tmpc = c*t
     tmps = s*t
     for i, ii in enumerate(unique_idx):
-        line_r[i] = tmpc + eqsf.Rmag[ii]
-        line_z[i] = tmps + eqsf.Zmag[ii]
+        line_r[i] = tmpc + eqm.Rmag[ii]
+        line_z[i] = tmps + eqm.Zmag[ii]
  
-    rho_line = rz2rho(eqsf, line_r, line_z, eqsf.time[unique_idx], \
+    rho_line = rz2rho(eqm, line_r, line_z, eqm.time[unique_idx], \
                            coord_out=coord_in , extrapolate=True)
 
     R = np.empty((nt_in, ntheta) + rho.shape[1:], dtype=np.float32)
     z = np.empty((nt_in, ntheta) + rho.shape[1:], dtype=np.float32)
 
     if coord_in == 'Psi':
-        rho_line[:,:,0] = eqsf.psi0[unique_idx][:,None]
-        rho_line *= eqsf.orientation
-        rho      *= eqsf.orientation
+        rho_line[:,:,0] = eqm.psi0[unique_idx][:,None]
+        rho_line *= eqm.orientation
+        rho      *= eqm.orientation
     else:
         #solve some issues very close to the core
         rho_line[:,:,0] = 0
@@ -755,7 +755,7 @@ def rhoTheta2rz(eqsf, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     return R, z
 
 
-def mag_theta_star(eqsf, t_in, n_rho=400, n_theta=200, rz_grid=False ):
+def mag_theta_star(eqm, t_in, n_rho=400, n_theta=200, rz_grid=False ):
     
     """
     Computes theta star 
@@ -779,11 +779,11 @@ def mag_theta_star(eqsf, t_in, n_rho=400, n_theta=200, rz_grid=False ):
     rho = np.linspace(0, 1, n_rho+1)[1:]
     theta = np.linspace(0, 2*np.pi, n_theta, endpoint=False)
 
-    magr, magz = rhoTheta2rz(eqsf, rho, theta, t_in=t_in, coord_in='rho_pol')
+    magr, magz = rhoTheta2rz(eqm, rho, theta, t_in=t_in, coord_in='rho_pol')
     magr, magz = magr[0].T, magz[0].T
     
-    r0 = np.interp(t_in, eqsf.time, eqsf.Rmag)
-    z0 = np.interp(t_in, eqsf.time, eqsf.Zmag)
+    r0 = np.interp(t_in, eqm.time, eqm.Rmag)
+    z0 = np.interp(t_in, eqm.time, eqm.Zmag)
 
     drdrho, drtheta = np.gradient(magr)
     dzdrho, dztheta = np.gradient(magz)
@@ -832,3 +832,22 @@ def mag_theta_star(eqsf, t_in, n_rho=400, n_theta=200, rz_grid=False ):
     theta_star = np.arctan2(sin_grid, cos_grid)
 
     return rgrid, zgrid, theta_star
+
+
+def get_q_surf(eqm, qvalue=1, t_in=None, coord_out='rho_tor'):
+
+    if t_in is None:
+        t_in = eqm.time
+    tarr = np.atleast_1d(t_in)
+    unique_idx, idx = get_nearest_index(eqm.time, tarr)
+
+    rho_surf = []
+    rho_q = rho2rho(eqm, eqm.pfl[unique_idx], t_in=t_in, coord_in='Psi', coord_out=coord_out)
+
+    for i in unique_idx:
+        (jt, ) = np.where(idx == i)[0]
+        (nrho, ) = eqm.lpfp[i]
+        q_surf = np.interp(qvalue, np.abs(eqm.q[i, :nrho]), rho_q[jt, :nrho], left=np.nan, right=np.nan)
+        rho_surf.append(q_surf)
+
+    return np.squeeze(rho_surf)
